@@ -140,36 +140,36 @@ class ExternalBackendConf(SharedBackendConfUtils):
         self._jconf.useManualClusterStart()
         return self
 
-    def setH2OCluster(self, value):
-        self._jconf.setH2OCluster(value)
+    def setH2OCluster(self, *args):
+        self._jconf.setH2OCluster(*args)
         return self
 
-    def setClusterSize(self, value):
-        self._jconf.setClusterSize(value)
+    def setClusterSize(self, clusterSize):
+        self._jconf.setClusterSize(clusterSize)
         return self
 
-    def setClusterStartTimeout(self, value):
-        self._jconf.setClusterStartTimeout(value)
+    def setClusterStartTimeout(self, clusterStartTimeout):
+        self._jconf.setClusterStartTimeout(clusterStartTimeout)
         return self
 
-    def setClusterInfoFile(self, value):
-        self._jconf.setClusterInfoFile(value)
+    def setClusterInfoFile(self, path):
+        self._jconf.setClusterInfoFile(path)
         return self
 
-    def setExternalMemory(self, value):
-        self._jconf.setExternalMemory(value)
+    def setExternalMemory(self, memory):
+        self._jconf.setExternalMemory(memory)
         return self
 
-    def setHDFSOutputDir(self, value):
-        self._jconf.setHDFSOutputDir(value)
+    def setHDFSOutputDir(self, dir):
+        self._jconf.setHDFSOutputDir(dir)
         return self
 
-    def setH2ODriverPath(self, value):
-        self._jconf.setH2ODriverPath(value)
+    def setH2ODriverPath(self, path):
+        self._jconf.setH2ODriverPath(path)
         return self
 
-    def setYARNQueue(self, value):
-        self._jconf.setYARNQueue(value)
+    def setYARNQueue(self, queueName):
+        self._jconf.setYARNQueue(queueName)
         return self
 
     def setKillOnUnhealthyClusterEnabled(self):
@@ -180,82 +180,82 @@ class ExternalBackendConf(SharedBackendConfUtils):
         self._jconf.setKillOnUnhealthyClusterDisabled()
         return self
 
-    def setKerberosPrincipal(self, value):
-        self._jconf.setKerberosPrincipal(value)
+    def setKerberosPrincipal(self, principal):
+        self._jconf.setKerberosPrincipal(principal)
         return self
 
-    def setKerberosKeytab(self, value):
-        self._jconf.setKerberosKeytab(value)
+    def setKerberosKeytab(self, path):
+        self._jconf.setKerberosKeytab(path)
         return self
 
-    def setRunAsUser(self, value):
-        self._jconf.setRunAsUser(value)
+    def setRunAsUser(self, user):
+        self._jconf.setRunAsUser(user)
         return self
 
-    def setExternalH2ODriverIf(self, value):
-        self._jconf.setExternalH2ODriverIf(value)
+    def setExternalH2ODriverIf(self, iface):
+        self._jconf.setExternalH2ODriverIf(iface)
         return self
 
-    def setExternalH2ODriverPort(self, value):
-        self._jconf.setExternalH2ODriverPort(value)
+    def setExternalH2ODriverPort(self, port):
+        self._jconf.setExternalH2ODriverPort(port)
         return self
 
-    def setExternalH2ODriverPortRange(self, value):
-        self._jconf.setExternalH2ODriverPortRange(value)
+    def setExternalH2ODriverPortRange(self, portRange):
+        self._jconf.setExternalH2ODriverPortRange(portRange)
         return self
 
-    def setExternalExtraMemoryPercent(self, value):
-        self._jconf.setExternalExtraMemoryPercent(value)
+    def setExternalExtraMemoryPercent(self, memoryPercent):
+        self._jconf.setExternalExtraMemoryPercent(memoryPercent)
         return self
 
-    def setExternalBackendStopTimeout(self, value):
-        self._jconf.setExternalBackendStopTimeout(value)
+    def setExternalBackendStopTimeout(self, timeout):
+        self._jconf.setExternalBackendStopTimeout(timeout)
         return self
 
-    def setExternalHadoopExecutable(self, value):
-        self._jconf.setExternalHadoopExecutable(value)
+    def setExternalHadoopExecutable(self, executable):
+        self._jconf.setExternalHadoopExecutable(executable)
         return self
 
-    def setExternalExtraJars(self, value):
-        self._jconf.setExternalExtraJars(value)
+    def setExternalExtraJars(self, *args):
+        self._jconf.setExternalExtraJars(*args)
         return self
 
-    def setExternalCommunicationCompression(self, value):
-        self._jconf.setExternalCommunicationCompression(value)
+    def setExternalCommunicationCompression(self, compressionType):
+        self._jconf.setExternalCommunicationCompression(compressionType)
         return self
 
-    def setExternalAutoStartBackend(self, value):
-        self._jconf.setExternalAutoStartBackend(value)
+    def setExternalAutoStartBackend(self, backend):
+        self._jconf.setExternalAutoStartBackend(backend)
         return self
 
-    def setExternalK8sH2OServiceName(self, value):
-        self._jconf.setExternalK8sH2OServiceName(value)
+    def setExternalK8sH2OServiceName(self, serviceName):
+        self._jconf.setExternalK8sH2OServiceName(serviceName)
         return self
 
-    def setExternalK8sH2OStatefulsetName(self, value):
-        self._jconf.setExternalK8sH2OStatefulsetName(value)
+    def setExternalK8sH2OStatefulsetName(self, statefulsetName):
+        self._jconf.setExternalK8sH2OStatefulsetName(statefulsetName)
         return self
 
-    def setExternalK8sH2OLabel(self, value):
-        self._jconf.setExternalK8sH2OLabel(value)
+    def setExternalK8sH2OLabel(self, label):
+        self._jconf.setExternalK8sH2OLabel(label)
         return self
 
-    def setExternalK8sH2OApiPort(self, value):
-        self._jconf.setExternalK8sH2OApiPort(value)
+    def setExternalK8sH2OApiPort(self, port):
+        self._jconf.setExternalK8sH2OApiPort(port)
         return self
 
-    def setExternalK8sNamespace(self, value):
-        self._jconf.setExternalK8sNamespace(value)
+    def setExternalK8sNamespace(self, namespace):
+        self._jconf.setExternalK8sNamespace(namespace)
         return self
 
-    def setExternalK8sDockerImage(self, value):
-        self._jconf.setExternalK8sDockerImage(value)
+    def setExternalK8sDockerImage(self, name):
+        self._jconf.setExternalK8sDockerImage(name)
         return self
 
-    def setExternalK8sDomain(self, value):
-        self._jconf.setExternalK8sDomain(value)
+    def setExternalK8sDomain(self, domain):
+        self._jconf.setExternalK8sDomain(domain)
         return self
 
-    def setExternalK8sServiceTimeout(self, value):
-        self._jconf.setExternalK8sServiceTimeout(value)
+    def setExternalK8sServiceTimeout(self, timeout):
+        self._jconf.setExternalK8sServiceTimeout(timeout)
         return self
