@@ -28,6 +28,9 @@ class InternalBackendConf(SharedBackendConfUtils):
     def numH2OWorkers(self):
         return self._get_option(self._jconf.numH2OWorkers())
 
+    def extraClusterNodes(self):
+        return self._jconf.extraClusterNodes()
+
     def drddMulFactor(self):
         return self._jconf.drddMulFactor()
 
@@ -46,42 +49,54 @@ class InternalBackendConf(SharedBackendConfUtils):
     def spreadRddRetriesTimeout(self):
         return self._jconf.spreadRddRetriesTimeout()
 
-    def nodeIcedDir(self):
-        return self._get_option(self._jconf.nodeIcedDir())
+    def isDirectIpConfigurationEnabled(self):
+        return self._jconf.isDirectIpConfigurationEnabled()
 
 
     #
     # Setters
     #
 
-    def setNumH2OWorkers(self, value):
-        self._jconf.setNumH2OWorkers(value)
+    def setNumH2OWorkers(self, numWorkers):
+        self._jconf.setNumH2OWorkers(numWorkers)
         return self
 
-    def setDrddMulFactor(self, value):
-        self._jconf.setDrddMulFactor(value)
+    def setExtraClusterNodesEnabled(self):
+        self._jconf.setExtraClusterNodesEnabled()
         return self
 
-    def setNumRddRetries(self, value):
-        self._jconf.setNumRddRetries(value)
+    def setExtraClusterNodesDisabled(self):
+        self._jconf.setExtraClusterNodesDisabled()
         return self
 
-    def setDefaultCloudSize(self, value):
-        self._jconf.setDefaultCloudSize(value)
+    def setDrddMulFactor(self, factor):
+        self._jconf.setDrddMulFactor(factor)
         return self
 
-    def setSubseqTries(self, value):
-        self._jconf.setSubseqTries(value)
+    def setNumRddRetries(self, retries):
+        self._jconf.setNumRddRetries(retries)
         return self
 
-    def setHdfsConf(self, value):
-        self._jconf.setHdfsConf(value)
+    def setDefaultCloudSize(self, defaultClusterSize):
+        self._jconf.setDefaultCloudSize(defaultClusterSize)
         return self
 
-    def setSpreadRddRetriesTimeout(self, value):
-        self._jconf.setSpreadRddRetriesTimeout(value)
+    def setSubseqTries(self, subseqTriesNum):
+        self._jconf.setSubseqTries(subseqTriesNum)
         return self
 
-    def setNodeIcedDir(self, value):
-        self._jconf.setNodeIcedDir(value)
+    def setHdfsConf(self, *args):
+        self._jconf.setHdfsConf(*args)
+        return self
+
+    def setSpreadRddRetriesTimeout(self, timeout):
+        self._jconf.setSpreadRddRetriesTimeout(timeout)
+        return self
+
+    def setDirectIpConfigurationEnabled(self):
+        self._jconf.setDirectIpConfigurationEnabled()
+        return self
+
+    def setDirectIpConfigurationDisabled(self):
+        self._jconf.setDirectIpConfigurationDisabled()
         return self
