@@ -17,7 +17,7 @@
 
 from warnings import warn
 from pyspark import keyword_only
-from ai.h2o.sparkling import Initializer
+from ai.h2o.sparkling.Initializer import Initializer
 from ai.h2o.sparkling.ml.Utils import Utils
 from ai.h2o.sparkling.ml.algos.H2OGAM import H2OGAM
 
@@ -43,7 +43,6 @@ class H2OGAMRegressor(H2OGAM):
                  convertUnknownCategoricalLevelsToNa=False,
                  splitRatio=1.0,
                  withStageResults=False,
-                 withDetailedPredictionCol=True,
                  seed=-1,
                  family="AUTO",
                  tweedieVariancePower=0.0,
@@ -77,6 +76,7 @@ class H2OGAMRegressor(H2OGAM):
                  computePValues=False,
                  removeCollinearCols=False,
                  numKnots=None,
+                 splineOrders=None,
                  scale=None,
                  bs=None,
                  keepGamCols=False,
