@@ -17,7 +17,7 @@
 
 from warnings import warn
 from pyspark import keyword_only
-from ai.h2o.sparkling import Initializer
+from ai.h2o.sparkling.Initializer import Initializer
 from ai.h2o.sparkling.ml.Utils import Utils
 from ai.h2o.sparkling.ml.algos.H2OXGBoost import H2OXGBoost
 
@@ -43,7 +43,6 @@ class H2OXGBoostRegressor(H2OXGBoost):
                  convertUnknownCategoricalLevelsToNa=False,
                  splitRatio=1.0,
                  withStageResults=False,
-                 withDetailedPredictionCol=True,
                  ntrees=50,
                  maxDepth=6,
                  minRows=1.0,
@@ -67,6 +66,7 @@ class H2OXGBoostRegressor(H2OXGBoost):
                  buildTreeOneNode=False,
                  saveMatrixDirectory=None,
                  calibrateModel=False,
+                 calibrationMethod="AUTO",
                  maxBins=256,
                  maxLeaves=0,
                  treeMethod="auto",
