@@ -20,10 +20,9 @@ from ai.h2o.sparkling.ml.params.H2OTypeConverters import H2OTypeConverters
 from ai.h2o.sparkling.ml.params.HasInitialBiases import HasInitialBiases
 from ai.h2o.sparkling.ml.params.HasInitialWeights import HasInitialWeights
 from ai.h2o.sparkling.ml.params.HasIgnoredCols import HasIgnoredCols
-from ai.h2o.sparkling.ml.params.HasDeprecatedVariableImportances import HasDeprecatedVariableImportances
 
 
-class H2ODeepLearningParams(HasInitialBiases, HasInitialWeights, HasIgnoredCols, HasDeprecatedVariableImportances, Params):
+class H2ODeepLearningParams(HasInitialBiases, HasInitialWeights, HasIgnoredCols, Params):
 
     ##
     # Param definitions
@@ -244,12 +243,6 @@ class H2ODeepLearningParams(HasInitialBiases, HasInitialWeights, HasIgnoredCols,
         """If enabled, override the final model with the best model found during training.""",
         H2OTypeConverters.toBoolean())
 
-    autoencoder = Param(
-        Params._dummy(),
-        "autoencoder",
-        """Auto-Encoder.""",
-        H2OTypeConverters.toBoolean())
-
     useAllFactorLevels = Param(
         Params._dummy(),
         "useAllFactorLevels",
@@ -433,7 +426,7 @@ class H2ODeepLearningParams(HasInitialBiases, HasInitialWeights, HasIgnoredCols,
     weightCol = Param(
         Params._dummy(),
         "weightCol",
-        """Column with observation weights. Giving some observation a weight of zero is equivalent to excluding it from the dataset; giving an observation a relative weight of 2 is equivalent to repeating that row twice. Negative weights are not allowed. Note: Weights are per-row observation weights and do not increase the size of the data frame. This is typically the number of times a row is repeated, but non-integer values are supported as well. During training, rows with higher weights matter more, due to the larger loss function pre-factor.""",
+        """Column with observation weights. Giving some observation a weight of zero is equivalent to excluding it from the dataset; giving an observation a relative weight of 2 is equivalent to repeating that row twice. Negative weights are not allowed. Note: Weights are per-row observation weights and do not increase the size of the data frame. This is typically the number of times a row is repeated, but non-integer values are supported as well. During training, rows with higher weights matter more, due to the larger loss function pre-factor. If you set weight = 0 for a row, the returned prediction frame at that row is zero and this is incorrect. To get an accurate prediction, remove all rows with weight == 0.""",
         H2OTypeConverters.toNullableString())
 
     offsetCol = Param(
@@ -619,9 +612,6 @@ class H2ODeepLearningParams(HasInitialBiases, HasInitialWeights, HasIgnoredCols,
     def getOverwriteWithBestModel(self):
         return self.getOrDefault(self.overwriteWithBestModel)
 
-    def getAutoencoder(self):
-        return self.getOrDefault(self.autoencoder)
-
     def getUseAllFactorLevels(self):
         return self.getOrDefault(self.useAllFactorLevels)
 
@@ -862,9 +852,6 @@ class H2ODeepLearningParams(HasInitialBiases, HasInitialWeights, HasIgnoredCols,
     def setOverwriteWithBestModel(self, value):
         return self._set(overwriteWithBestModel=value)
 
-    def setAutoencoder(self, value):
-        return self._set(autoencoder=value)
-
     def setUseAllFactorLevels(self, value):
         return self._set(useAllFactorLevels=value)
 
