@@ -53,6 +53,12 @@ class H2OGLMParams(HasRandomCols, HasIgnoredCols, HasPlugValues, HasBetaConstrai
         """Tweedie variance power""",
         H2OTypeConverters.toFloat())
 
+    dispersionLearningRate = Param(
+        Params._dummy(),
+        "dispersionLearningRate",
+        """Dispersion learning rate is only valid for tweedie family dispersion parameter estimation using ml. It must be > 0.  This controls how much the dispersion parameter estimate is to be changed when the calculated loglikelihood actually decreases with the new dispersion.  In this case, instead of setting new dispersion = dispersion - change, we set new dispersion = dispersion + dispersion_learning_rate * change. Defaults to 0.5.""",
+        H2OTypeConverters.toFloat())
+
     tweedieLinkPower = Param(
         Params._dummy(),
         "tweedieLinkPower",
@@ -146,19 +152,19 @@ class H2OGLMParams(HasRandomCols, HasIgnoredCols, HasPlugValues, HasBetaConstrai
     objectiveEpsilon = Param(
         Params._dummy(),
         "objectiveEpsilon",
-        """Converge if  objective value changes less than this. Default indicates: If lambda_search is set to True the value of objective_epsilon is set to .0001. If the lambda_search is set to False and lambda is equal to zero, the value of objective_epsilon is set to .000001, for any other value of lambda the default value of objective_epsilon is set to .0001.""",
+        """Converge if  objective value changes less than this. Default (of -1.0) indicates: If lambda_search is set to True the value of objective_epsilon is set to .0001. If the lambda_search is set to False and lambda is equal to zero, the value of objective_epsilon is set to .000001, for any other value of lambda the default value of objective_epsilon is set to .0001.""",
         H2OTypeConverters.toFloat())
 
     gradientEpsilon = Param(
         Params._dummy(),
         "gradientEpsilon",
-        """Converge if  objective changes less (using L-infinity norm) than this, ONLY applies to L-BFGS solver. Default indicates: If lambda_search is set to False and lambda is equal to zero, the default value of gradient_epsilon is equal to .000001, otherwise the default value is .0001. If lambda_search is set to True, the conditional values above are 1E-8 and 1E-6 respectively.""",
+        """Converge if  objective changes less (using L-infinity norm) than this, ONLY applies to L-BFGS solver. Default (of -1.0) indicates: If lambda_search is set to False and lambda is equal to zero, the default value of gradient_epsilon is equal to .000001, otherwise the default value is .0001. If lambda_search is set to True, the conditional values above are 1E-8 and 1E-6 respectively.""",
         H2OTypeConverters.toFloat())
 
     objReg = Param(
         Params._dummy(),
         "objReg",
-        """Likelihood divider in objective value computation, default is 1/nobs""",
+        """Likelihood divider in objective value computation, default (of -1.0) will set it to 1/nobs""",
         H2OTypeConverters.toFloat())
 
     link = Param(
@@ -167,6 +173,12 @@ class H2OGLMParams(HasRandomCols, HasIgnoredCols, HasPlugValues, HasBetaConstrai
         """Link function.""",
         H2OTypeConverters.toEnumString("hex.glm.GLMModel$GLMParameters$Link"))
 
+    dispersionParameterMethod = Param(
+        Params._dummy(),
+        "dispersionParameterMethod",
+        """Method used to estimate the dispersion parameter for Tweedie, Gamma and Negative Binomial only.""",
+        H2OTypeConverters.toEnumString("hex.glm.GLMModel$GLMParameters$DispersionMethod"))
+
     randomLink = Param(
         Params._dummy(),
         "randomLink",
@@ -185,12 +197,36 @@ class H2OGLMParams(HasRandomCols, HasIgnoredCols, HasPlugValues, HasBetaConstrai
         """if true, will return likelihood function value for HGLM.""",
         H2OTypeConverters.toBoolean())
 
+    generateVariableInflationFactors = Param(
+        Params._dummy(),
+        "generateVariableInflationFactors",
+        """if true, will generate variable inflation factors for numerical predictors.  Default to false.""",
+        H2OTypeConverters.toBoolean())
+
     intercept = Param(
         Params._dummy(),
         "intercept",
         """Include constant term in the model""",
         H2OTypeConverters.toBoolean())
 
+    buildNullModel = Param(
+        Params._dummy(),
+        "buildNullModel",
+        """If set, will build a model with only the intercept.  Default to false.""",
+        H2OTypeConverters.toBoolean())
+
+    fixDispersionParameter = Param(
+        Params._dummy(),
+        "fixDispersionParameter",
+        """Only used for Tweedie, Gamma and Negative Binomial GLM.  If set, will use the dispsersion parameter in init_dispersion_parameter as the standard error and use it to calculate the p-values. Default to false.""",
+        H2OTypeConverters.toBoolean())
+
+    initDispersionParameter = Param(
+        Params._dummy(),
+        "initDispersionParameter",
+        """Only used for Tweedie, Gamma and Negative Binomial GLM.  Store the initial value of dispersion parameter.  If fix_dispersion_parameter is set, this value will be used in the calculation of p-values.Default to 1.0.""",
+        H2OTypeConverters.toFloat())
+
     HGLM = Param(
         Params._dummy(),
         "HGLM",
@@ -251,12 +287,36 @@ class H2OGLMParams(HasRandomCols, HasIgnoredCols, HasPlugValues, HasBetaConstrai
         """Request p-values computation, p-values work only with IRLSM solver and no regularization""",
         H2OTypeConverters.toBoolean())
 
+    fixTweedieVariancePower = Param(
+        Params._dummy(),
+        "fixTweedieVariancePower",
+        """If true, will fix tweedie variance power value to the value set in tweedie_variance_power.""",
+        H2OTypeConverters.toBoolean())
+
     removeCollinearCols = Param(
         Params._dummy(),
         "removeCollinearCols",
         """In case of linearly dependent columns, remove some of the dependent columns""",
         H2OTypeConverters.toBoolean())
 
+    dispersionEpsilon = Param(
+        Params._dummy(),
+        "dispersionEpsilon",
+        """If changes in dispersion parameter estimation or loglikelihood value is smaller than dispersion_epsilon, will break out of the dispersion parameter estimation loop using maximum likelihood.""",
+        H2OTypeConverters.toFloat())
+
+    tweedieEpsilon = Param(
+        Params._dummy(),
+        "tweedieEpsilon",
+        """In estimating tweedie dispersion parameter using maximum likelihood, this is used to choose the lower and upper indices in the approximating of the infinite series summation.""",
+        H2OTypeConverters.toFloat())
+
+    maxIterationsDispersion = Param(
+        Params._dummy(),
+        "maxIterationsDispersion",
+        """Control the maximum number of iterations in the dispersion parameter estimation loop using maximum likelihood.""",
+        H2OTypeConverters.toInt())
+
     generateScoringHistory = Param(
         Params._dummy(),
         "generateScoringHistory",
@@ -398,6 +458,9 @@ class H2OGLMParams(HasRandomCols, HasIgnoredCols, HasPlugValues, HasBetaConstrai
     def getTweedieVariancePower(self):
         return self.getOrDefault(self.tweedieVariancePower)
 
+    def getDispersionLearningRate(self):
+        return self.getOrDefault(self.dispersionLearningRate)
+
     def getTweedieLinkPower(self):
         return self.getOrDefault(self.tweedieLinkPower)
 
@@ -455,6 +518,9 @@ class H2OGLMParams(HasRandomCols, HasIgnoredCols, HasPlugValues, HasBetaConstrai
     def getLink(self):
         return self.getOrDefault(self.link)
 
+    def getDispersionParameterMethod(self):
+        return self.getOrDefault(self.dispersionParameterMethod)
+
     def getRandomLink(self):
         return self.getOrDefault(self.randomLink)
 
@@ -464,9 +530,21 @@ class H2OGLMParams(HasRandomCols, HasIgnoredCols, HasPlugValues, HasBetaConstrai
     def getCalcLike(self):
         return self.getOrDefault(self.calcLike)
 
+    def getGenerateVariableInflationFactors(self):
+        return self.getOrDefault(self.generateVariableInflationFactors)
+
     def getIntercept(self):
         return self.getOrDefault(self.intercept)
 
+    def getBuildNullModel(self):
+        return self.getOrDefault(self.buildNullModel)
+
+    def getFixDispersionParameter(self):
+        return self.getOrDefault(self.fixDispersionParameter)
+
+    def getInitDispersionParameter(self):
+        return self.getOrDefault(self.initDispersionParameter)
+
     def getHGLM(self):
         return self.getOrDefault(self.HGLM)
 
@@ -497,9 +575,21 @@ class H2OGLMParams(HasRandomCols, HasIgnoredCols, HasPlugValues, HasBetaConstrai
     def getComputePValues(self):
         return self.getOrDefault(self.computePValues)
 
+    def getFixTweedieVariancePower(self):
+        return self.getOrDefault(self.fixTweedieVariancePower)
+
     def getRemoveCollinearCols(self):
         return self.getOrDefault(self.removeCollinearCols)
 
+    def getDispersionEpsilon(self):
+        return self.getOrDefault(self.dispersionEpsilon)
+
+    def getTweedieEpsilon(self):
+        return self.getOrDefault(self.tweedieEpsilon)
+
+    def getMaxIterationsDispersion(self):
+        return self.getOrDefault(self.maxIterationsDispersion)
+
     def getGenerateScoringHistory(self):
         return self.getOrDefault(self.generateScoringHistory)
 
@@ -578,6 +668,9 @@ class H2OGLMParams(HasRandomCols, HasIgnoredCols, HasPlugValues, HasBetaConstrai
     def setTweedieVariancePower(self, value):
         return self._set(tweedieVariancePower=value)
 
+    def setDispersionLearningRate(self, value):
+        return self._set(dispersionLearningRate=value)
+
     def setTweedieLinkPower(self, value):
         return self._set(tweedieLinkPower=value)
 
@@ -635,6 +728,9 @@ class H2OGLMParams(HasRandomCols, HasIgnoredCols, HasPlugValues, HasBetaConstrai
     def setLink(self, value):
         return self._set(link=value)
 
+    def setDispersionParameterMethod(self, value):
+        return self._set(dispersionParameterMethod=value)
+
     def setRandomLink(self, value):
         return self._set(randomLink=value)
 
@@ -644,9 +740,21 @@ class H2OGLMParams(HasRandomCols, HasIgnoredCols, HasPlugValues, HasBetaConstrai
     def setCalcLike(self, value):
         return self._set(calcLike=value)
 
+    def setGenerateVariableInflationFactors(self, value):
+        return self._set(generateVariableInflationFactors=value)
+
     def setIntercept(self, value):
         return self._set(intercept=value)
 
+    def setBuildNullModel(self, value):
+        return self._set(buildNullModel=value)
+
+    def setFixDispersionParameter(self, value):
+        return self._set(fixDispersionParameter=value)
+
+    def setInitDispersionParameter(self, value):
+        return self._set(initDispersionParameter=value)
+
     def setHGLM(self, value):
         return self._set(HGLM=value)
 
@@ -677,9 +785,21 @@ class H2OGLMParams(HasRandomCols, HasIgnoredCols, HasPlugValues, HasBetaConstrai
     def setComputePValues(self, value):
         return self._set(computePValues=value)
 
+    def setFixTweedieVariancePower(self, value):
+        return self._set(fixTweedieVariancePower=value)
+
     def setRemoveCollinearCols(self, value):
         return self._set(removeCollinearCols=value)
 
+    def setDispersionEpsilon(self, value):
+        return self._set(dispersionEpsilon=value)
+
+    def setTweedieEpsilon(self, value):
+        return self._set(tweedieEpsilon=value)
+
+    def setMaxIterationsDispersion(self, value):
+        return self._set(maxIterationsDispersion=value)
+
     def setGenerateScoringHistory(self, value):
         return self._set(generateScoringHistory=value)
 
