@@ -162,9 +162,15 @@ class H2OXGBoostParams(HasMonotoneConstraints, HasCalibrationDataFrame, HasIgnor
     calibrateModel = Param(
         Params._dummy(),
         "calibrateModel",
-        """Use Platt Scaling to calculate calibrated class probabilities. Calibration can provide more accurate estimates of class probabilities.""",
+        """Use Platt Scaling (default) or Isotonic Regression to calculate calibrated class probabilities. Calibration can provide more accurate estimates of class probabilities.""",
         H2OTypeConverters.toBoolean())
 
+    calibrationMethod = Param(
+        Params._dummy(),
+        "calibrationMethod",
+        """Calibration method to use""",
+        H2OTypeConverters.toEnumString("hex.tree.CalibrationHelper$CalibrationMethod"))
+
     maxBins = Param(
         Params._dummy(),
         "maxBins",
@@ -258,8 +264,8 @@ class H2OXGBoostParams(HasMonotoneConstraints, HasCalibrationDataFrame, HasIgnor
     gpuId = Param(
         Params._dummy(),
         "gpuId",
-        """Which GPU to use. """,
-        H2OTypeConverters.toInt())
+        """Which GPU(s) to use. """,
+        H2OTypeConverters.toNullableListInt())
 
     interactionConstraints = Param(
         Params._dummy(),
@@ -267,6 +273,12 @@ class H2OXGBoostParams(HasMonotoneConstraints, HasCalibrationDataFrame, HasIgnor
         """A set of allowed column interactions.""",
         H2OTypeConverters.toNullableListListString())
 
+    scalePosWeight = Param(
+        Params._dummy(),
+        "scalePosWeight",
+        """Controls the effect of observations with positive labels in relation to the observations with negative labels on gradient calculation. Useful for imbalanced problems.""",
+        H2OTypeConverters.toFloat())
+
     modelId = Param(
         Params._dummy(),
         "modelId",
@@ -318,7 +330,7 @@ class H2OXGBoostParams(HasMonotoneConstraints, HasCalibrationDataFrame, HasIgnor
     weightCol = Param(
         Params._dummy(),
         "weightCol",
-        """Column with observation weights. Giving some observation a weight of zero is equivalent to excluding it from the dataset; giving an observation a relative weight of 2 is equivalent to repeating that row twice. Negative weights are not allowed. Note: Weights are per-row observation weights and do not increase the size of the data frame. This is typically the number of times a row is repeated, but non-integer values are supported as well. During training, rows with higher weights matter more, due to the larger loss function pre-factor.""",
+        """Column with observation weights. Giving some observation a weight of zero is equivalent to excluding it from the dataset; giving an observation a relative weight of 2 is equivalent to repeating that row twice. Negative weights are not allowed. Note: Weights are per-row observation weights and do not increase the size of the data frame. This is typically the number of times a row is repeated, but non-integer values are supported as well. During training, rows with higher weights matter more, due to the larger loss function pre-factor. If you set weight = 0 for a row, the returned prediction frame at that row is zero and this is incorrect. To get an accurate prediction, remove all rows with weight == 0.""",
         H2OTypeConverters.toNullableString())
 
     offsetCol = Param(
@@ -393,6 +405,12 @@ class H2OXGBoostParams(HasMonotoneConstraints, HasCalibrationDataFrame, HasIgnor
         """Automatically export generated models to this directory.""",
         H2OTypeConverters.toNullableString())
 
+    aucType = Param(
+        Params._dummy(),
+        "aucType",
+        """Set default multinomial AUC type.""",
+        H2OTypeConverters.toEnumString("hex.MultinomialAucType"))
+
     ##
     # Getters
     ##
@@ -465,6 +483,9 @@ class H2OXGBoostParams(HasMonotoneConstraints, HasCalibrationDataFrame, HasIgnor
     def getCalibrateModel(self):
         return self.getOrDefault(self.calibrateModel)
 
+    def getCalibrationMethod(self):
+        return self.getOrDefault(self.calibrationMethod)
+
     def getMaxBins(self):
         return self.getOrDefault(self.maxBins)
 
@@ -516,6 +537,9 @@ class H2OXGBoostParams(HasMonotoneConstraints, HasCalibrationDataFrame, HasIgnor
     def getInteractionConstraints(self):
         return self.getOrDefault(self.interactionConstraints)
 
+    def getScalePosWeight(self):
+        return self.getOrDefault(self.scalePosWeight)
+
     def getModelId(self):
         return self.getOrDefault(self.modelId)
 
@@ -579,6 +603,9 @@ class H2OXGBoostParams(HasMonotoneConstraints, HasCalibrationDataFrame, HasIgnor
     def getExportCheckpointsDir(self):
         return self.getOrDefault(self.exportCheckpointsDir)
 
+    def getAucType(self):
+        return self.getOrDefault(self.aucType)
+
     ##
     # Setters
     ##
@@ -651,6 +678,9 @@ class H2OXGBoostParams(HasMonotoneConstraints, HasCalibrationDataFrame, HasIgnor
     def setCalibrateModel(self, value):
         return self._set(calibrateModel=value)
 
+    def setCalibrationMethod(self, value):
+        return self._set(calibrationMethod=value)
+
     def setMaxBins(self, value):
         return self._set(maxBins=value)
 
@@ -702,6 +732,9 @@ class H2OXGBoostParams(HasMonotoneConstraints, HasCalibrationDataFrame, HasIgnor
     def setInteractionConstraints(self, value):
         return self._set(interactionConstraints=value)
 
+    def setScalePosWeight(self, value):
+        return self._set(scalePosWeight=value)
+
     def setModelId(self, value):
         return self._set(modelId=value)
 
@@ -764,3 +797,6 @@ class H2OXGBoostParams(HasMonotoneConstraints, HasCalibrationDataFrame, HasIgnor
 
     def setExportCheckpointsDir(self, value):
         return self._set(exportCheckpointsDir=value)
+
+    def setAucType(self, value):
+        return self._set(aucType=value)
